@@ -59,18 +59,8 @@ class PraatLoader:
         com = [self.praat, os.path.join(self.script_dir,name)] + map(str,args)
         if self.debug:
             self.updatelog('%s' % str(com))
-        orig = os.getuid()
-        os.setuid(1000)
-        if self.debug:
-            self.updatelog('orignal user: %s' % str(orig))
-            self.updatelog('now user: %s' % str(os.getuid()))
         p = subprocess.Popen(com,stdout=subprocess.PIPE,stderr=subprocess.PIPE,stdin=subprocess.PIPE)
         stdout, stderr = p.communicate()
-        if self.debug:
-            self.updatelog('now user: %s' % str(os.getuid()))
-        os.setuid(orig)
-        if self.debug:
-            self.updatelog('now user: %s' % str(os.getuid()))
         if self.debug:
             self.updatelog('stdout: %s' % str(stdout))
             self.updatelog('stderr: %s' % str(stderr))
@@ -83,6 +73,8 @@ class PraatLoader:
 
     def read_praat_out(self,text):
         output = []
+        if text == '':
+            return output
         lines = text.splitlines()
         head = lines.pop(0).split("\t")
         for l in lines:
